common

package
v0.0.0-...-337ca53 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 18, 2019 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ConfigBasePath string

ConfigBasePath stores the base path of where to find the config.json file

Functions

This section is empty.

Types

type Configuration

type Configuration struct {
	Fullscreen bool    // if should run in fullscreen mode
	Scale      float64 // window's scale
	Width      int     // window's width
	Height     int     // window's height
}

Configuration defines the configuration for the engine, it is loaded from a config.json file

func LoadConfigurations

func LoadConfigurations() *Configuration

LoadConfigurations loads all configurations from config.json and makes a Configuration struct from it

Jump to