Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ConfigBasePath string
ConfigBasePath stores the base path of where to find the config.json file
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
Fullscreen bool // if should run in fullscreen mode
Scale float64 // window's scale
Width int // window's width
Height int // window's height
}
Configuration defines the configuration for the engine, it is loaded from a config.json file
func LoadConfigurations ¶
func LoadConfigurations() *Configuration
LoadConfigurations loads all configurations from config.json and makes a Configuration struct from it
Click to show internal directories.
Click to hide internal directories.